/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gnome;
import org.gnu.glib.Handle;
import org.gnu.glib.Type;
/**
 *
 */
public class CanvasShape extends CanvasItem {

	protected CanvasShape(CanvasGroup group, int type) {
		super(group, type);
	}
	
	/**
	 * Constructs an instance of CanvasShape from a native widget resource.
	 * @param handle The handle to the native widget.
	 */
	CanvasShape(Handle handle) {
		super(handle);
	}

	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gnome_canvas_shape_get_type());
	}


	native static final protected int gnome_canvas_shape_get_type();
	native static final protected void gnome_canvas_shape_set_path_def(Handle shape, Handle def);
	native static final protected Handle gnome_canvas_shape_get_path_def(Handle shape);

}
